@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.1;
 
-our $VERSION = '1.778_03';
+our $VERSION = '1.778_04';
 
 use Exporter qw( import );
 
@@ -18,9 +18,9 @@ our @EXPORT_OK = qw( table_char_width );
 
 sub table_char_width { [
 #[     0x0,     0x1f, -1],
-[    0x20,     0x7e, 1],
+#[    0x20,     0x7e, 1],
 #[    0x7f,     0x9f, -1],
-[    0xa0,    0x2ff, 1],
+#[    0xa0,    0x2ff, 1],
 [   0x300,    0x36f, 0],
 [   0x370,    0x482, 1],
 [   0x483,    0x489, 0],
@@ -1016,7 +1016,7 @@ sub table_char_width { [
 [ 0xe0020,  0xe007f, 0],
 [ 0xe0080,  0xe00ff, 1],
 [ 0xe0100,  0xe01ef, 0],
-[ 0xe01f0, 0x10ffff, 1],
+#[ 0xe01f0, 0x10ffff, 1],
 ] }
 
 
